@@ -5,8 +5,11 @@
 
 START_EXTERN_C
 
+typedef UV hook_op_check_id;
+
 typedef OP *(*hook_op_check_cb) (pTHX_ OP *, void *);
-void hook_op_check (opcode type, hook_op_check_cb cb, void *user_data);
+hook_op_check_id hook_op_check (opcode type, hook_op_check_cb cb, void *user_data);
+void *hook_op_check_remove (opcode type, hook_op_check_id id);
 
 END_EXTERN_C
 
